==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/SectionInformationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SectionInformationDescription } from "./SectionInformationDescription";
/**
 * @hidden
 */
var SectionInformationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SectionInformationDescriptionMetadata, _super);
    function SectionInformationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SectionInformationDescriptionMetadata.b = function (a) {
        if (SectionInformationDescriptionMetadata.a == null) {
            SectionInformationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SectionInformationDescriptionMetadata.c(SectionInformationDescriptionMetadata.a);
        }
        if (a.g(SectionInformationDescriptionMetadata.a)) {
            return;
        }
        a.s(SectionInformationDescriptionMetadata.a);
    };
    SectionInformationDescriptionMetadata.c = function (a) {
    };
    SectionInformationDescriptionMetadata.d = function (a) {
        SectionInformationDescriptionMetadata.b(a);
        a.u("SectionInformation", function () { return new SectionInformationDescription(); });
        a.t("SectionInformation", SectionInformationDescriptionMetadata.a);
    };
    SectionInformationDescriptionMetadata.$t = markType(SectionInformationDescriptionMetadata, 'SectionInformationDescriptionMetadata');
    SectionInformationDescriptionMetadata.a = null;
    return SectionInformationDescriptionMetadata;
}(Base));
export { SectionInformationDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SectionInformationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SectionInformationDescription } from "./SectionInformationDescription";
/**
 * @hidden
 */
var SectionInformationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SectionInformationDescriptionMetadata, _super);
    function SectionInformationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SectionInformationDescriptionMetadata.b = function (a) {
        if (SectionInformationDescriptionMetadata.a == null) {
            SectionInformationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SectionInformationDescriptionMetadata.c(SectionInformationDescriptionMetadata.a);
        }
        if (a.j(SectionInformationDescriptionMetadata.a)) {
            return;
        }
        a.y(SectionInformationDescriptionMetadata.a);
    };
    SectionInformationDescriptionMetadata.c = function (a) {
    };
    SectionInformationDescriptionMetadata.d = function (a) {
        SectionInformationDescriptionMetadata.b(a);
        a.aa("SectionInformation", function () { return new SectionInformationDescription(); });
        a.z("SectionInformation", SectionInformationDescriptionMetadata.a);
    };
    SectionInformationDescriptionMetadata.$t = markType(SectionInformationDescriptionMetadata, 'SectionInformationDescriptionMetadata');
    SectionInformationDescriptionMetadata.a = null;
    return SectionInformationDescriptionMetadata;
}(Base));
export { SectionInformationDescriptionMetadata };
